.. oHySEM documentation master file, created by Erik Alvarez

Publications
============

The **oHySEM** model has been used in these publications:

- E.F. Alvarez, P. Sánchez-Martín and A. Ramos, "Self-Scheduling for a Hydrogen-Based Virtual Power Plant in Day-Ahead Energy and Reserve Electricity Markets," 20th International Conference on the European Energy Market (EEM), Istanbul, Turkiye, June 2024, pp. 1-6, `10.1109/EEM60825.2024.10608848 <https://doi.org/10.1109/EEM60825.2024.10608848>`_. (`Presentation <https://github.com/IIT-EnergySystemModels/oHySEM/blob/main/doc/pdf/EEM24_presentation.pdf>`_)
